﻿using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace XNACS1Lib {

    /// <summary>
    /// A particle primitive, inherits from circle but draws using additive blending.
    /// Used in particleEmitters as well.
    /// </summary>
    public class XNACS1Particle : XNACS1Circle {

        internal int m_ParticleLife;
       
        /// <summary>
        /// Constructs the particle
        /// </summary>
        /// <param name="center">center of particle</param>
        /// <param name="size">radius of particle</param>
        /// <param name="life">Life parameter, used by emitters, autodecrements by one each tick if larger than zero.</param>
        public XNACS1Particle(Vector2 center, float size, int life)
            : this(center, size, life,null) {}

        /// <summary>
        /// Constructs the particle
        /// </summary>
        /// <param name="center">Center of particle.</param>
        /// <param name="size">Radius of particle.</param>
        /// <param name="life">Life parameter, used by emitters, autodecrements by one each tick if larger than zero.</param>
        /// <param name="tex">Texture to be used by particle.</param>
        public XNACS1Particle(Vector2 center, float size, int life, string tex) : base(center,size,tex) {
            m_ParticleLife = life;
        }

        /// <summary>
        /// Draws the particle.
        /// </summary>
        protected override void DrawPrimitive() {
            if (sm_DrawHelper.m_CurrentBlendMode != SpriteBlendMode.Additive) {
                sm_DrawHelper.EndDraw();
                sm_DrawHelper.BeginDraw(SpriteBlendMode.Additive);
            }
            if (m_UseSpriteSheet && m_SpriteSourceRect != null)
                sm_DrawHelper.DrawCircle(m_Center, Radius, m_SpriteSourceRect, m_Rotate, m_TextureColor, m_Texture);
            else
                sm_DrawHelper.DrawCircle(m_Center, Radius, null, m_Rotate, m_TextureColor, m_Texture);
        }

        /// <summary>
        /// Gets or sets the life parameter of a particle.
        /// </summary>
        public int Life {
            get { return m_ParticleLife; }
            set { m_ParticleLife = value; }
        }

        /// <summary>
        /// Reduces the life of a particle by one if it is greater than zero, then calls base.TravelPrimitive.
        /// </summary>
        public override void TravelPrimitive() {
            if (m_ParticleLife > 0) m_ParticleLife--;
            base.TravelPrimitive();
        }
        
    }
}
