﻿using System;
using System.IO;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
using Microsoft.Xna.Framework.Content;

namespace XNACS1Lib {
    class XNACS1Particle : XNACS1Circle {

        internal float m_ParticleLife;

        public XNACS1Particle(Vector2 center, float size, float life)
            : this(center, size, life, null,null) {}
        public XNACS1Particle(Vector2 center, float size, float life, string tex)
            : this(center, size, life, null, tex) {
        }

        public XNACS1Particle(Vector2 center, float size, float life, XNACS1Primitive drawAbove)
            : this(center, size, life, drawAbove, null) {
        }
        public XNACS1Particle(Vector2 center, float size, float life, XNACS1Primitive drawAbove, string tex) {
            InitParticle(PrimitiveType.PrimitiveCircle, center, new Vector2(2.0f * size, 2.0f * size), tex);
            if (null != drawAbove)
                m_DrawOrder = drawAbove.m_DrawOrder;
            else
                m_DrawOrder = sm_DrawHelper.m_SortCurrentTop;
            m_ParticleLife = life;
        }

        private void InitParticle (PrimitiveType p, Vector2 c, Vector2 s, String tex) {
            m_Center = c;
            m_Size = s;
            m_Velocity = new Vector2(1, 0); // This cannot be zero!! Otherwise Speed will not work!!
            m_ShouldTravel = false;

            m_Type = p;
            m_Rotate = 0.0f; // rotate angle and FrontDirection are tied together in 1-1
            m_FrontDirection = new Vector2(1, 0); // initial front direction for all prtimives is in the positive X-direction
            m_NormalDirection = new Vector2(0, 1);
            m_Texture = tex;

            m_Color = Color.Aquamarine;

            m_Label = null;
            m_LabelColor = Color.Black;

            m_CenterReference = true;

            m_Visible = true;

            //sprite sheet info init
            m_UseSpriteSheet = false;
            m_UseSpriteSheetAnimation = false;
            m_SpriteSheetColumns = 0;
            m_SpriteSheetRows = 0;
            m_SpriteSheetPadding = 0;
            m_SpriteCurrentFrame = -1;
            m_SpriteBeginFrame = 0;
            m_SpriteEndFrame = 0;
            m_TicksPerFrame = 1;
            m_CurrentFrameTicks = 0;
            m_SpriteFrameInc = 1;
            m_SpriteAnimMode = SpriteSheetAnimationMode.AnimateForward;
            m_SpriteSourceRect = Rectangle.Empty;


            if (null != sm_DrawHelper) {
                // null should happen only once, for the system WorldRec
                AddToAutoDrawSet();
            }
        }



        public override void RemoveFromAutoDrawSet() {
            sm_DrawHelper.RemoveFromSet(this);
        }

        //perhaps drawing like a circle will be fine
       // protected override void DrawPrimitive() {
         
       // }

        public override void AddToAutoDrawSet() {
            sm_DrawHelper.AddToSet(this);
        }

        public override bool IsInAutoDrawSet() {
            return sm_DrawHelper.IsInDrawSet(this);
        }

        public override void  TopOfAutoDrawSet()
        {
 	        //do nothing particles blend additive anyway?
        }

        
    }
}
